@@ -1,7 +1,6 @@
 "use strict";
-var match = [/https?:\/\/(www\.|beta\.)?facebook.com\/video.php\?.*/];
+var match = [/https?:\/\/(www\.|beta\.)?facebook.com\/(.*\/videos\/.*|video.php\?.*)/];
 var inject = [
-    "common.js",
     "facebook.js"
 ];
 exports.match = match;
